From 1b12fea0fa8f55d1fc7d38ab0aff7aa041b35431 Mon Sep 17 00:00:00 2001
From: Bob-the-Kuhn <bob.kuhn@att.net>
Date: Wed, 12 Apr 2017 14:35:31 -0500
Subject: [PATCH] simplified M20 with size

---
 Marlin/cardreader.cpp | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/Marlin/cardreader.cpp b/Marlin/cardreader.cpp
index 08d8671011..ff0b8a4cf2 100644
--- a/Marlin/cardreader.cpp
+++ b/Marlin/cardreader.cpp
@@ -74,7 +74,7 @@ char *createFilename(char *buffer, const dir_t &p) { //buffer > 12characters
  * Dive into a folder and recurse depth-first to perform a pre-set operation lsAction:
  *   LS_Count       - Add +1 to nrFiles for every file within the parent
  *   LS_GetFilename - Get the filename of the file indexed by nrFiles
  *   LS_SerialPrint - Print the full path of each file to serial output
  */
 void CardReader::lsDive(const char *prepend, SdFile parent, const char * const match/*=NULL*/) {
   dir_t p;
@@ -133,11 +133,15 @@ void CardReader::lsDive(const char *prepend, SdFile parent, const char * const m
         case LS_Count:
           nrFiles++;
           break;
+
         case LS_SerialPrint:
           createFilename(filename, p);
           SERIAL_PROTOCOL(prepend);
-          SERIAL_PROTOCOLLN(filename);
+          SERIAL_PROTOCOL(filename);
+          SERIAL_PROTOCOLCHAR(' ');
+          SERIAL_PROTOCOLLN(p.fileSize);
           break;
+
         case LS_GetFilename:
           createFilename(filename, p);
           if (match != NULL) {
@@ -74,7 +74,7 @@ char *createFilename(char *buffer, const dir_t &p) { //buffer > 12characters
  *   LS_Count       - Add +1 to nrFiles for every file within the parent
  *   LS_GetFilename - Get the filename of the file indexed by nrFiles
- *   LS_SerialPrint - Print the full path of each file to serial output
+ *   LS_SerialPrint - Print the full path and size of each file to serial output
  */
 void CardReader::lsDive(const char *prepend, SdFile parent, const char * const match/*=NULL*/) {